You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:13:57 UTC

svn commit: r1591061 [4/6] - in /openoffice/trunk/main/qadevOOo: runner/base/ runner/basicrunner/ runner/basicrunner/basichelper/ runner/complexlib/ runner/convwatch/ runner/graphical/ runner/helper/ runner/lib/ runner/org/openoffice/ runner/share/ run...

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_DatabaseImportDescriptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_DatabaseImportDescriptor.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_DatabaseImportDescriptor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_DatabaseImportDescriptor.java Tue Apr 29 19:13:51 2014
@@ -91,7 +91,7 @@ public class _DatabaseImportDescriptor e
                 tRes.tested(name, true);
             }
         } catch (Exception e) {
-             log.println("Exception occured while testing property '" +
+             log.println("Exception occurred while testing property '" +
                  name + "'");
              e.printStackTrace(log);
              tRes.tested(name, false);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_FunctionDescription.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_FunctionDescription.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_FunctionDescription.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_FunctionDescription.java Tue Apr 29 19:13:51 2014
@@ -89,7 +89,7 @@ public class _FunctionDescription extend
             }
         } catch (Exception e) {
             log.println(
-                "Exception occured while testing property 'Arguments'" );
+                "Exception occurred while testing property 'Arguments'" );
             e.printStackTrace( log );
             tRes.tested( "Arguments", false );
         }
@@ -141,7 +141,7 @@ public class _FunctionDescription extend
         }
         catch ( Exception e ) {
             log.println(
-                "Exception occured while testing property '" + name + "'" );
+                "Exception occurred while testing property '" + name + "'" );
             e.printStackTrace( log );
             tRes.tested( name, false );
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_SheetSortDescriptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_SheetSortDescriptor.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_SheetSortDescriptor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_SheetSortDescriptor.java Tue Apr 29 19:13:51 2014
@@ -129,7 +129,7 @@ public class _SheetSortDescriptor extend
                 tRes.tested(name, true);
             }
         } catch (Exception e) {
-             log.println("Exception occured while testing property '" +
+             log.println("Exception occurred while testing property '" +
                  name + "'");
              e.printStackTrace(log);
              tRes.tested(name, false);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XActivationBroadcaster.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XActivationBroadcaster.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XActivationBroadcaster.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XActivationBroadcaster.java Tue Apr 29 19:13:51 2014
@@ -70,7 +70,7 @@ public class _XActivationBroadcaster ext
         xSpreadsheetView.setActiveSheet(two);
 
         if (listenerCalled) {
-            log.println("Listener was called eventhough it is removed");
+            log.println("Listener was called even though it is removed");
         }
 
         xSpreadsheetView.setActiveSheet(org);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDataPilotTables.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDataPilotTables.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDataPilotTables.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDataPilotTables.java Tue Apr 29 19:13:51 2014
@@ -95,7 +95,7 @@ public class _XDataPilotTables extends M
             bResult &= oSheet.getCellByPosition
                 (CA.Column, CA.Row).getFormula().equals("Filter");
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured! " + e);
+            log.println("Exception occurred! " + e);
             bResult = false;
         }
 
@@ -132,7 +132,7 @@ public class _XDataPilotTables extends M
             bResult &= oSheet.getCellByPosition
                 (CA.Column, CA.Row).getFormula().equals("");
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured ! " + e);
+            log.println("Exception occurred ! " + e);
             bResult = false;
         }
         log.println(bResult ? "OK" : "FAILED");

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDatabaseRanges.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDatabaseRanges.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDatabaseRanges.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDatabaseRanges.java Tue Apr 29 19:13:51 2014
@@ -70,7 +70,7 @@ public class _XDatabaseRanges extends Mu
             log.println("Exception expected... Test failed.");
             bResult = false;
         } catch(com.sun.star.uno.RuntimeException e) {
-            log.println("Exception occured while testing addNewByName() : " + e);
+            log.println("Exception occurred while testing addNewByName() : " + e);
             bResult = true;
         }
 
@@ -80,7 +80,7 @@ public class _XDatabaseRanges extends Mu
     /**
     * Test removes the database range with name that exist exactly and then
     * tries to remove the range with name that doesn't exist exactly. <p>
-    * Has <b> OK </b> status if first range was succesfully removed and
+    * Has <b> OK </b> status if first range was successfully removed and
     * exception was thrown when trying to remove non-existent database range.<p>
     * The following method tests are to be completed successfully before :
     * <ul>
@@ -98,7 +98,7 @@ public class _XDatabaseRanges extends Mu
             oObj.removeByName(name);
             bResult &= !oObj.hasByName(name);
         } catch (com.sun.star.uno.RuntimeException e) {
-            log.println("Exception occured while testing removeByName() : " + e);
+            log.println("Exception occurred while testing removeByName() : " + e);
             bResult = false;
         }
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDocumentAuditing.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDocumentAuditing.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDocumentAuditing.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XDocumentAuditing.java Tue Apr 29 19:13:51 2014
@@ -182,7 +182,7 @@ public class _XDocumentAuditing extends 
 
     /**
      * Check if the amount of shapes is the right one after displaying that stuff
-     * 2do improve this: check taht the shapes are the correct ones -> convwatch
+     * 2do improve this: check that the shapes are the correct ones -> convwatch
      * @desiredValue That's the amount of shapes that have to be here.
      * @return True, if the actual count of shapes is the same
      */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XNamedRanges.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XNamedRanges.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XNamedRanges.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XNamedRanges.java Tue Apr 29 19:13:51 2014
@@ -278,7 +278,7 @@ public class _XNamedRanges extends Multi
             log.println("Exception expected when removed unexistent element!");
             bResult = false;
         } catch (com.sun.star.uno.RuntimeException e) {
-            log.println("Expected exception occured while testing" +
+            log.println("Expected exception occurred while testing" +
                       "removeByName() when removed unexistent element.");
 
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java Tue Apr 29 19:13:51 2014
@@ -174,7 +174,7 @@ public class _XSheetAuditing extends Mul
     
     /**
      * Check if the amount of shapes is the right one after displaying that stuff
-     * 2do improve this: check taht the shapes are the correct ones -> convwatch
+     * 2do improve this: check that the shapes are the correct ones -> convwatch
      * @desiredValue That's the amount of shapes that have to be here.
      * @return True, if the actual count of shapes is the same
      */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java Tue Apr 29 19:13:51 2014
@@ -254,7 +254,7 @@ public class _XSheetCellCursor extends M
         log.println("DB: Successfuly merged.") ;
 
         oObj.collapseToMergedArea() ;
-        log.println("DB: Succesfully collapseToMergedArea() method called");
+        log.println("DB: Successfully collapseToMergedArea() method called");
 
         // unmerge area to restore SpreadSheet
         mergeRange.merge(false);
@@ -267,7 +267,7 @@ public class _XSheetCellCursor extends M
         int rows = ((XColumnRowRange)
             UnoRuntime.queryInterface(
                 XColumnRowRange.class, oObj) ).getRows().getCount();
-        log.println("DB: Column and row numbers succesfully get") ;
+        log.println("DB: Column and row numbers successfully get") ;
 
         if (cols == width + 1  && rows == height + 3) {
             bResult &= true;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetOperation.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetOperation.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetOperation.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetOperation.java Tue Apr 29 19:13:51 2014
@@ -65,7 +65,7 @@ public class _XSheetOperation extends Mu
         } catch (com.sun.star.uno.Exception e) {
             result &= false ;
             log.println(
-                    "Exception occured while checking results of method");
+                    "Exception occurred while checking results of method");
             e.printStackTrace(log);
         }
 
@@ -89,7 +89,7 @@ public class _XSheetOperation extends Mu
             result = resultVal >= 0;
         } catch (com.sun.star.uno.Exception e) {
             result = false;
-            log.println("Exception occured in method computeFunction.");
+            log.println("Exception occurred in method computeFunction.");
             e.printStackTrace(log);
         }
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSpreadsheets.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSpreadsheets.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_CharacterProperties.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_CharacterProperties.java Tue Apr 29 19:13:51 2014
@@ -408,23 +408,23 @@ public class _CharacterProperties extend
                 tRes.tested(name,true);
             }
             else {
-                log.println("Exception occured while testing property '" +
+                log.println("Exception occurred while testing property '" +
                      name + "'");
                 ex.printStackTrace(log);
                 tRes.tested(name, false);
             }
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while testing property '" +
+            log.println("Exception occurred while testing property '" +
                 name + "'");
             e.printStackTrace(log);
             tRes.tested(name, false);
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured while testing property '" +
+            log.println("Exception occurred while testing property '" +
                  name + "'");
             e.printStackTrace(log);
             tRes.tested(name, false);
         } catch (com.sun.star.beans.PropertyVetoException e) {
-            log.println("Exception occured while testing property '" +
+            log.println("Exception occurred while testing property '" +
                  name + "'");
             e.printStackTrace(log);
             tRes.tested(name, false);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_ParagraphProperties.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_ParagraphProperties.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_ParagraphProperties.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_ParagraphProperties.java Tue Apr 29 19:13:51 2014
@@ -296,13 +296,13 @@ public class _ParagraphProperties extend
             oObj.setPropertyValue("ParaAdjust", 
                                   com.sun.star.style.ParagraphAdjust.BLOCK);
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured setting property 'ParagraphAdjust'" + e);
+            log.println("Exception occurred setting property 'ParagraphAdjust'" + e);
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured setting property 'ParagraphAdjust'" + e);
+            log.println("Exception occurred setting property 'ParagraphAdjust'" + e);
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured setting property 'ParagraphAdjust'" + e);
+            log.println("Exception occurred setting property 'ParagraphAdjust'" + e);
         } catch (com.sun.star.beans.PropertyVetoException e) {
-            log.println("Exception occured setting property 'ParagraphAdjust'" + e);
+            log.println("Exception occurred setting property 'ParagraphAdjust'" + e);
         }
 
         testProperty("ParaLastLineAdjust", ShortTester);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_XStyle.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_XStyle.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_XStyle.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_XStyle.java Tue Apr 29 19:13:51 2014
@@ -103,7 +103,7 @@ public class _XStyle extends MultiMethod
         try {
             oObj.setParentStyle(oMyStyle.getName());
         } catch (com.sun.star.container.NoSuchElementException e) {
-            log.println("Exception occured while method call: " + e);
+            log.println("Exception occurred while method call: " + e);
             result = false ;
         }
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/system/_XSystemShellExecute.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/system/_XSystemShellExecute.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/system/_XSystemShellExecute.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/system/_XSystemShellExecute.java Tue Apr 29 19:13:51 2014
@@ -46,7 +46,7 @@ public class _XSystemShellExecute extend
     public XSystemShellExecute oObj = null;
 
     /**
-    * Excecutes 'java SystemShellExecute SystemShellExecute.txt' command line.
+    * Executes 'java SystemShellExecute SystemShellExecute.txt' command line.
     * <p>Has <b> OK </b> status if the method successfully returns
     * and file 'SystemShellExecute.txt' was created. <p>
     */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/table/_XAutoFormattable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/table/_XAutoFormattable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/table/_XAutoFormattable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/table/_XAutoFormattable.java Tue Apr 29 19:13:51 2014
@@ -113,7 +113,7 @@ public class _XAutoFormattable extends M
 
             bResult &= !bkgrnd1.equals(bkgrnd2);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured :");
+            log.println("Exception occurred :");
             e.printStackTrace(log);
             bResult = false;
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_BaseIndex.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_BaseIndex.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_BaseIndex.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_BaseIndex.java Tue Apr 29 19:13:51 2014
@@ -130,13 +130,13 @@ public class _BaseIndex extends MultiPro
 
                     indProp.replaceByIndex(0, newVal);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while testing LevelFormat");
+                    log.println("Exception occurred while testing LevelFormat");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-                    log.println("Exception occured while testing LevelFormat");
+                    log.println("Exception occurred while testing LevelFormat");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while testing LevelFormat");
+                    log.println("Exception occurred while testing LevelFormat");
                     e.printStackTrace(log);
                 }
 
@@ -190,10 +190,10 @@ public class _BaseIndex extends MultiPro
                 }
             }
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while printing LevelFormat");
+            log.println("Exception occurred while printing LevelFormat");
             e.printStackTrace(log);
         } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-            log.println("Exception occured while printing LevelFormat");
+            log.println("Exception occurred while printing LevelFormat");
             e.printStackTrace(log);
         }
     }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XAutoTextGroup.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XAutoTextGroup.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XAutoTextGroup.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XAutoTextGroup.java Tue Apr 29 19:13:51 2014
@@ -74,7 +74,7 @@ public class _XAutoTextGroup extends Mul
      * Constructs a unique string for current interface thread
      * for naming purposes. All old entries which names are
      * started with prefix used for entry names, are deleted
-     * from the group (they can remain after previous unsuccessfull
+     * from the group (they can remain after previous unsuccessful
      * test runs). The relation is obtained.
      *
      * @throws StatusException if the relation is not found.
@@ -131,7 +131,7 @@ public class _XAutoTextGroup extends Mul
             result = !util.ValueComparer.equalValue(before, after);
         }
         catch (com.sun.star.container.ElementExistException ex) {
-            log.println("Exception occured while testing insertNewByName");
+            log.println("Exception occurred while testing insertNewByName");
             ex.printStackTrace(log);
             result = false;
         }
@@ -176,7 +176,7 @@ public class _XAutoTextGroup extends Mul
                 !ValueComparer.equalValue(before,after));
         }
         catch (com.sun.star.container.NoSuchElementException ex) {
-            log.println("Exception occured while testing removeByName");
+            log.println("Exception occurred while testing removeByName");
             ex.printStackTrace(log);
             tRes.tested("removeByName()",false);
         }
@@ -208,7 +208,7 @@ public class _XAutoTextGroup extends Mul
             names = oObj.getElementNames() ;
             result = true;
         } catch (com.sun.star.container.ElementExistException e) {
-            log.println("Unexpected exception occured :") ;
+            log.println("Unexpected exception occurred :") ;
             e.printStackTrace(log);
         } finally {
             if (!result) {
@@ -275,15 +275,15 @@ public class _XAutoTextGroup extends Mul
             oObj.renameByName(str,str+"a",str+"b");
             result &= oObj.hasByName(str + "a");
         } catch (com.sun.star.container.ElementExistException ex) {
-            log.println("Exception occured while testing renameByName");
+            log.println("Exception occurred while testing renameByName");
             ex.printStackTrace(log);
             result &=false;
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while testing renameByName");
+            log.println("Exception occurred while testing renameByName");
             ex.printStackTrace(log);
             result &=false;
         } catch (com.sun.star.io.IOException ex) {
-            log.println("Exception occured while testing renameByName");
+            log.println("Exception occurred while testing renameByName");
             ex.printStackTrace(log);
             result &=false;
         } finally {

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XDefaultNumberingProvider.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XDefaultNumberingProvider.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XDefaultNumberingProvider.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XDefaultNumberingProvider.java Tue Apr 29 19:13:51 2014
@@ -48,7 +48,7 @@ public class _XDefaultNumberingProvider 
     /**
     * Just gets numberings for "en" locale. <p>
     * Has <b>OK</b> status if not <code>null</code> value returned
-    * and no runtime exceptions occured.
+    * and no runtime exceptions occurred.
     */
     public void _getDefaultOutlineNumberings() {
         XIndexAccess xIA[] = oObj.getDefaultOutlineNumberings(loc) ;
@@ -59,7 +59,7 @@ public class _XDefaultNumberingProvider 
     /**
     * Just gets numberings for "en" locale. <p>
     * Has <b>OK</b> status if not <code>null</code> value returned
-    * and no runtime exceptions occured.
+    * and no runtime exceptions occurred.
     */
     public void _getDefaultContinuousNumberingLevels() {
         PropertyValue[][] lev = oObj.getDefaultContinuousNumberingLevels(loc) ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XRelativeTextContentInsert.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XRelativeTextContentInsert.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java Tue Apr 29 19:13:51 2014
@@ -137,7 +137,7 @@ public class _XCachedDynamicResultSetStu
             setFac = (XCachedDynamicResultSetFactory) UnoRuntime.queryInterface
                 (XCachedDynamicResultSetFactory.class, fac) ;
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Cant instantiate a service") ;
+            log.println("Can't instantiate a service") ;
             e.printStackTrace(log) ;
             result = false ;
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XContentProvider.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XContentProvider.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XContentProvider.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XContentProvider.java Tue Apr 29 19:13:51 2014
@@ -117,7 +117,7 @@ public class _XContentProvider extends M
         int compare = oObj.compareContentIds(CI,CI2);
         boolean res = (compare != 0);
         if (!res) {
-            log.println("Didn't work with differnt IDs");
+            log.println("Didn't work with different IDs");
             log.println(compare+" was returned");
         }
         compare = oObj.compareContentIds(CI,CI);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XDataContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XDataContainer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XDataContainer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XDataContainer.java Tue Apr 29 19:13:51 2014
@@ -50,7 +50,7 @@ public class _XDataContainer extends Mul
 
     /**
     * Sets the content type to some value. <p>
-    * Has <b>OK</b> status if no runtime exseptions occured.
+    * Has <b>OK</b> status if no runtime exseptions occurred.
     */
     public void _setContentType() {
         oObj.setContentType("image/jpeg") ;
@@ -74,7 +74,7 @@ public class _XDataContainer extends Mul
 
     /**
     * Sets the data to some byte array. <p>
-    * Has <b>OK</b> status if no runtime exseptions occured.
+    * Has <b>OK</b> status if no runtime exseptions occurred.
     */
     public void _setData() {
         oObj.setData(data) ;
@@ -105,7 +105,7 @@ public class _XDataContainer extends Mul
 
     /**
     * Sets the data URL to some URL. <p>
-    * Has <b>OK</b> status if no runtime exseptions occured.
+    * Has <b>OK</b> status if no runtime exseptions occurred.
     */
     public void _setDataURL() {
         dataURL = util.utils.getOfficeTemp((XMultiServiceFactory)tParam.getMSF()) ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess.java Tue Apr 29 19:13:51 2014
@@ -79,7 +79,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(copiedFile);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'copy()'");
+            log.println("Exception occurred while testing 'copy()'");
             ex.printStackTrace(log);
             tRes.tested("copy()",false);
         }
@@ -112,7 +112,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(copiedFile);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'move()'");
+            log.println("Exception occurred while testing 'move()'");
             ex.printStackTrace(log);
             tRes.tested("move()",false);
         }
@@ -141,7 +141,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("kill()",!oObj.exists(copiedFile));
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'kill()'");
+            log.println("Exception occurred while testing 'kill()'");
             ex.printStackTrace(log);
             tRes.tested("kill()",false);
         }
@@ -158,7 +158,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("isFolder()",oObj.isFolder(dirname));
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'isFolder()'");
+            log.println("Exception occurred while testing 'isFolder()'");
             ex.printStackTrace(log);
             tRes.tested("isFolder()",false);
         }
@@ -203,7 +203,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(readonlyCopy);
             tRes.tested("isReadOnly()",result);
         } catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'isReadOnly()'");
+            log.println("Exception occurred while testing 'isReadOnly()'");
             ex.printStackTrace(log);
             tRes.tested("isReadOnly()",false);
         }
@@ -250,7 +250,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(readonlyCopy);
         }
         catch (Exception ex) {
-            log.println("Exception occured while testing 'setReadOnly()'");
+            log.println("Exception occurred while testing 'setReadOnly()'");
             ex.printStackTrace(log);
             tRes.tested("setReadOnly()",false);
         }
@@ -274,7 +274,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(newFolder);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'createFolder()'");
+            log.println("Exception occurred while testing 'createFolder()'");
             ex.printStackTrace(log);
             tRes.tested("createFolder()",false);
         }
@@ -296,7 +296,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("getSize()", fSize == 17 );
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'getSize()'");
+            log.println("Exception occurred while testing 'getSize()'");
             ex.printStackTrace(log);
             tRes.tested("getSize()",false);
         }
@@ -320,7 +320,7 @@ public class _XSimpleFileAccess extends 
                 "application/vnd.sun.staroffice.fsys-file".equals(fType) );
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'getContentType()'");
+            log.println("Exception occurred while testing 'getContentType()'");
             ex.printStackTrace(log);
             tRes.tested("getContentType()",false);
         }
@@ -372,7 +372,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("getDateTimeModified()", res);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'getDateTimeModified()'");
+            log.println("Exception occurred while testing 'getDateTimeModified()'");
             ex.printStackTrace(log);
             tRes.tested("getDateTimeModified()",false);
         }
@@ -393,7 +393,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("getFolderContents()", cont.length>0);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'getFolderContents()'");
+            log.println("Exception occurred while testing 'getFolderContents()'");
             ex.printStackTrace(log);
             tRes.tested("getFolderContents()",false);
         }
@@ -417,7 +417,7 @@ public class _XSimpleFileAccess extends 
                 oObj.exists(filename) && !oObj.exists(wrongname));
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'exists()'");
+            log.println("Exception occurred while testing 'exists()'");
             ex.printStackTrace(log);
             tRes.tested("exists()",false);
         }
@@ -439,7 +439,7 @@ public class _XSimpleFileAccess extends 
             tRes.tested("openFileRead()", iStream != null);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'openFileRead()'");
+            log.println("Exception occurred while testing 'openFileRead()'");
             ex.printStackTrace(log);
             tRes.tested("openFileRead()",false);
         }
@@ -470,7 +470,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(copiedFile);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'openFileWrite()'");
+            log.println("Exception occurred while testing 'openFileWrite()'");
             ex.printStackTrace(log);
             tRes.tested("openFileWrite()",false);
         }
@@ -502,7 +502,7 @@ public class _XSimpleFileAccess extends 
             oObj.kill(copiedFile);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'openFileReadWrite()'");
+            log.println("Exception occurred while testing 'openFileReadWrite()'");
             ex.printStackTrace(log);
             tRes.tested("openFileReadWrite()",false);
         }
@@ -527,7 +527,7 @@ public class _XSimpleFileAccess extends 
             oObj.setInteractionHandler(handler);
             tRes.tested("setInteractionHandler()", true);
         } catch (Exception ex) {
-            log.println("Exception occured while testing 'setInteractionHandler()'");
+            log.println("Exception occurred while testing 'setInteractionHandler()'");
             ex.printStackTrace(log);
             tRes.tested("setInteractionHandler()", false);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess2.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess2.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess2.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSimpleFileAccess2.java Tue Apr 29 19:13:51 2014
@@ -59,13 +59,13 @@ public class _XSimpleFileAccess2 extends
             tRes.tested("writeFile()",result);
         }
         catch (com.sun.star.ucb.CommandAbortedException ex) {
-            log.println("CommandAbortedException occured while testing "+
+            log.println("CommandAbortedException occurred while testing "+
                 "'writeFile()'");
             ex.printStackTrace(log);
             tRes.tested("writeFile()",false);
         }
         catch (com.sun.star.uno.Exception ex) {
-            log.println("Exception occured while testing 'writeFile()'");
+            log.println("Exception occurred while testing 'writeFile()'");
             ex.printStackTrace(log);
             tRes.tested("writeFile()",false);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java Tue Apr 29 19:13:51 2014
@@ -140,7 +140,7 @@ public class _XSortedDynamicResultSetFac
                 rowCount = set.getRow();
                 log.println("Number of rows in result set: " + rowCount);
             } catch (com.sun.star.sdbc.SQLException e) {
-                log.println("Exception occured while accessing "+
+                log.println("Exception occurred while accessing "+
                     "sorted result set :");
                 e.printStackTrace(log);
             }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePicker.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePicker.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePicker.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePicker.java Tue Apr 29 19:13:51 2014
@@ -52,7 +52,7 @@ public class _XFilePicker extends MultiM
 
     /**
     * Sets the current directory to the test document directory. <p>
-    * Has <b>OK</b> status if no exceptions occured.
+    * Has <b>OK</b> status if no exceptions occurred.
     */
     public void _setDisplayDirectory() {
         boolean result = true ;
@@ -91,7 +91,7 @@ public class _XFilePicker extends MultiM
     /**
     * Sets default name to file name existing in test document
     * directory ('space-metal.jpg'). <p>
-    * Has <b>OK</b> status if no exceptions occured.
+    * Has <b>OK</b> status if no exceptions occurred.
     */
     public void _setDefaultName() {
         boolean result = true ;
@@ -109,7 +109,7 @@ public class _XFilePicker extends MultiM
     /**
     * Just switch object to MultiSelectionMode. There is no ways
     * to check this method (only interactively). <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _setMultiSelectionMode() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerControlAccess.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerControlAccess.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerControlAccess.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerControlAccess.java Tue Apr 29 19:13:51 2014
@@ -48,7 +48,7 @@ import com.sun.star.ui.dialogs.XFilePick
 *    <code>Short</code>) : control identifier in the extended
 *    FilePicker dialog. </li>
 *  <li> <code>'XFilePickerControlAccess.ControlValue'</code> (of type
-*    <code>Object</code>) <b>optional</b> (but mostly desireable
+*    <code>Object</code>) <b>optional</b> (but mostly desirable
 *    since the control has emtpy initial value):
 *    the value which can set for the control . </li>
 * <ul> <p>
@@ -79,7 +79,7 @@ public class _XFilePickerControlAccess e
 
     /**
     * Gets the value of the control and stores it. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getValue() {
         boolean result = true ;
@@ -132,7 +132,7 @@ public class _XFilePickerControlAccess e
 
     /**
     * Gets the label of the control and stores it. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getLabel() {
 
@@ -178,7 +178,7 @@ public class _XFilePickerControlAccess e
     /**
     * Disables and then enables the control. Can be checked only
     * interactively. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _enableControl() {
         boolean result = true ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerNotifier.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerNotifier.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerNotifier.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilePickerNotifier.java Tue Apr 29 19:13:51 2014
@@ -104,9 +104,9 @@ public class _XFilePickerNotifier extend
                 (XFilePicker.class, oObj) ;
         
         if (fps == null) {
-            log.println("The object doesnt implement XFilePicker") ;
+            log.println("The object doesn't implement XFilePicker") ;
             throw new StatusException(Status.failed
-                    ("The object doesnt implement XFilePicker"));
+                    ("The object doesn't implement XFilePicker"));
         }
         
         XExecutableDialog exD = (XExecutableDialog) UnoRuntime.queryInterface(

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilterManager.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilterManager.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilterManager.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFilterManager.java Tue Apr 29 19:13:51 2014
@@ -60,7 +60,7 @@ public class _XFilterManager extends Mul
 
     /**
     * Sets the current filter to that which was appended before.<p>
-    * Has <b>OK</b> status if no exceptions occured, else one of
+    * Has <b>OK</b> status if no exceptions occurred, else one of
     * <code>appendFilter</code> and <code>setCurrentFilter</code>
     * methods failed. <p>
     * The following method tests are to be completed successfully before :

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFolderPicker.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFolderPicker.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFolderPicker.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/ui/dialogs/_XFolderPicker.java Tue Apr 29 19:13:51 2014
@@ -45,7 +45,7 @@ public class _XFolderPicker extends Mult
 
     /**
     * Sets the current directory to SOffice temp dir. <p>
-    * Has <b>OK</b> status if no exceptions occured.
+    * Has <b>OK</b> status if no exceptions occurred.
     */
     public void _setDisplayDirectory() {
         boolean result = true ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/uno/_XComponentContext.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/uno/_XComponentContext.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/uno/_XComponentContext.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/uno/_XComponentContext.java Tue Apr 29 19:13:51 2014
@@ -52,7 +52,7 @@ public class _XComponentContext extends 
                 log.println("worked .... ok");
                 res &= true;
             } catch (com.sun.star.uno.Exception e) {
-                log.println("Exception occured " + e.getMessage());
+                log.println("Exception occurred " + e.getMessage());
                 res &= false;
             }
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCancellable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCancellable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCancellable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCancellable.java Tue Apr 29 19:13:51 2014
@@ -42,7 +42,7 @@ public class _XCancellable extends Multi
 
     /**
      * Just calls the method. <p>
-     * Has <b>OK</b> status if no exception has occured. <p>
+     * Has <b>OK</b> status if no exception has occurred. <p>
      */
     public void _cancel() {
         oObj.cancel() ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCloneable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCloneable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCloneable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XCloneable.java Tue Apr 29 19:13:51 2014
@@ -47,7 +47,7 @@ public class _XCloneable extends MultiMe
     
     /**
      * calls the method. <p>
-     * Has <b>OK</b> status if no exception has occured. <p>
+     * Has <b>OK</b> status if no exception has occurred. <p>
      */
     public void _createClone() {
         boolean result = true;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XFlushable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XFlushable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XFlushable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XFlushable.java Tue Apr 29 19:13:51 2014
@@ -64,7 +64,7 @@ public class _XFlushable extends MultiMe
     /**
     * Test call method <code>flush</code> and checks if added listener
     * was called and removed one wasn't. <p>
-    * Has OK status if no exception has occured. <p>
+    * Has OK status if no exception has occurred. <p>
     *     Methods to be executed before :
     * {@link #_addFlushListener},
     * {@link #_removeFlushListener}

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModeSelector.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModeSelector.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModeSelector.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModeSelector.java Tue Apr 29 19:13:51 2014
@@ -46,7 +46,7 @@ public class _XModeSelector extends Mult
     /**
     * Calls the method and as argument pass one of the supported modes
     * that was returned by method getSupportedMode.<p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _setMode() {
         requiredMethod("getSupportedModes()");
@@ -63,7 +63,7 @@ public class _XModeSelector extends Mult
 
     /**
     * Calls the method and check returned value.<p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * and returned value is equal to value that was set by method setMode.
     */
     public void _getMode() {
@@ -74,7 +74,7 @@ public class _XModeSelector extends Mult
 
     /**
     * Calls the method and checks value returned by method.<p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * and returned value is not null.
     */
     public void _getSupportedModes() {
@@ -87,7 +87,7 @@ public class _XModeSelector extends Mult
     * by method getSupportedMode is passed as argument.
     * Then the method is called again and the mode that is certainly not supported
     * is passed. Checks up returned values in both cases.<p>
-    * Has <b> OK </b> status if no runtime exceptions occured,
+    * Has <b> OK </b> status if no runtime exceptions occurred,
     * returned value is true in first call and is false in second call.
     */
     public void _supportsMode() {

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModifyBroadcaster.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModifyBroadcaster.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModifyBroadcaster.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XModifyBroadcaster.java Tue Apr 29 19:13:51 2014
@@ -60,7 +60,7 @@ public class _XModifyBroadcaster extends
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _addModifyListener() {
         log.println("'Modified' events are called only in case"+
@@ -71,7 +71,7 @@ public class _XModifyBroadcaster extends
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _removeModifyListener() {
         requiredMethod("addModifyListener()");

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XSearchable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XSearchable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XSearchable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XSearchable.java Tue Apr 29 19:13:51 2014
@@ -125,7 +125,7 @@ public class _XSearchable extends MultiM
 
     /**
      * Performs search using descriptor created before. Storing the
-     * first occurence result. <p>
+     * first occurrence result. <p>
      * Has <b> OK </b> status if the method not <code>null</code>
      * value. <p>
      * The following method tests are to be completed successfully before :

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XTextSearch.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XTextSearch.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XTextSearch.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/util/_XTextSearch.java Tue Apr 29 19:13:51 2014
@@ -56,7 +56,7 @@ public class _XTextSearch extends MultiM
     /**
     * Sets options for searching regular expression in a string,
     * ignoring case. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _setOptions() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XControlAccess.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XControlAccess.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XControlAccess.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XControlAccess.java Tue Apr 29 19:13:51 2014
@@ -105,13 +105,13 @@ public class _XControlAccess extends Mul
 
             bResult &= oControl != null;
         } catch (com.sun.star.container.NoSuchElementException e) {
-            log.println("Exception occured calling the method: " + e);
+            log.println("Exception occurred calling the method: " + e);
             bResult = false;
         } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-            log.println("Exception occured calling the method: " + e);
+            log.println("Exception occurred calling the method: " + e);
             bResult = false;
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured calling the method: " + e);
+            log.println("Exception occurred calling the method: " + e);
             bResult = false;
         }
         tRes.tested("getControl()", bResult);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XSelectionSupplier.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XSelectionSupplier.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XSelectionSupplier.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/view/_XSelectionSupplier.java Tue Apr 29 19:13:51 2014
@@ -101,7 +101,7 @@ public class _XSelectionSupplier extends
             oObj.select(selections[1]);
             res = selectionChanged;
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured during addSelectionChangeListener()");
+            log.println("Exception occurred during addSelectionChangeListener()");
             ex.printStackTrace(log);
             res = false;
         }
@@ -147,7 +147,7 @@ public class _XSelectionSupplier extends
                 }
             }
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured during select()");
+            log.println("Exception occurred during select()");
             ex.printStackTrace(log);
             res = false;
         }
@@ -175,7 +175,7 @@ public class _XSelectionSupplier extends
             oObj.select(selections[1]);
             res = !selectionChanged;
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured during removeSelectionChangeListener()");
+            log.println("Exception occurred during removeSelectionChangeListener()");
             ex.printStackTrace(log);
             res = false;
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_acceptor/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_acceptor/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'acceptor'.</P>
+<P>Contains all test cases for the module 'acceptor'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_brdgfctr/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_brdgfctr/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_brdgfctr/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_brdgfctr/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'brdgfctr'.</P>
+<P>Contains all test cases for the module 'brdgfctr'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_bridgefac.uno/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_bridgefac.uno/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_bridgefac.uno/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_bridgefac.uno/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'brdgfctr'.</P>
+<P>Contains all test cases for the module 'brdgfctr'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_connector.uno/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_connector.uno/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_connector.uno/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_connector.uno/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'connectr'.</P>
+<P>Contains all test cases for the module 'connectr'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_connectr/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_connectr/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_connectr/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_connectr/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'connectr'.</P>
+<P>Contains all test cases for the module 'connectr'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_corefl/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_corefl/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_corefl/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_corefl/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'corefl'.</P>
+<P>Contains all test cases for the module 'corefl'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_corereflection.uno/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_corereflection.uno/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_corereflection.uno/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_corereflection.uno/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'corefl'.</P>
+<P>Contains all test cases for the module 'corefl'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_cpld/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_cpld/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_cpld/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_cpld/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'cpld'.</P>
+<P>Contains all test cases for the module 'cpld'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ORowSet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ORowSet.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ORowSet.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ORowSet.java Tue Apr 29 19:13:51 2014
@@ -208,7 +208,7 @@ public class ORowSet extends TestCase {
     /**
     * Creating a Testenvironment for the interfaces to be tested.
     * The database (DBF) file is copied from test document directory
-    * into SOffice temp dir with unique name for each enviroment
+    * into SOffice temp dir with unique name for each environment
     * creation. If the file cann't be copied (is not released)
     * then another unique name is used (file name suffix incremented
     * by 1).<p>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'dbaccess'.</P>
+<P>Contains all test cases for the module 'dbaccess'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java Tue Apr 29 19:13:51 2014
@@ -151,9 +151,9 @@ public class NestedRegistry extends Test
             copyFile(source, openF, log) ;
             copyFile(source, mergeF, log) ;
         } catch (java.io.IOException e) {
-            log.println("Exception occured while copying files");
+            log.println("Exception occurred while copying files");
             e.printStackTrace(log);
-            throw new StatusException("Exception occured while copying files", e);
+            throw new StatusException("Exception occurred while copying files", e);
         }
 
         try {

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_defreg/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'defreg'.</P>
+<P>Contains all test cases for the module 'defreg'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_fileacc/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_fileacc/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_fileacc/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_fileacc/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'fileacc'.</P>
+<P>Contains all test cases for the module 'fileacc'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java Tue Apr 29 19:13:51 2014
@@ -257,7 +257,7 @@ public class GenericModelTest extends Te
                 if (myForm == null){
                     log.println("ERROR: could not get 'Standard' from drawpage!");
                 }
-                log.println("the draw page contains folowing elemtens:");
+                log.println("the draw page contains following elemtens:");
                 String[] elements = FormTools.getForms(WriterTools.getDrawPage(m_xTextDoc)).getElementNames();
                 for (int i = 0; i< elements.length; i++){
                     log.println("Element[" + i + "] :" + elements[i]);
@@ -360,7 +360,7 @@ public class GenericModelTest extends Te
      *  <li> <code>'XUpdateBroadcaster.Checker'</code> : <code>
      *    _XUpdateBroadcaster.UpdateChecker</code> interface implementation
      *    which can update, commit data and check if the data was successfully
-     *    commited.</li>
+     *    committed.</li>
      *  <li> <code>'DataAwareControlModel.NewFieldName'</code> : for
      *    <code>com.sun.star.form.DataAwareControlModel</code> service
      *    which contains new name of the field ('_DATE') to bind control to.

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'forms'.</P>
+<P>Contains all test cases for the module 'forms'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_fwk/JobExecutor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_fwk/JobExecutor.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_fwk/JobExecutor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_fwk/JobExecutor.java Tue Apr 29 19:13:51 2014
@@ -94,7 +94,7 @@ public class JobExecutor extends TestCas
      * </ol>. <p>
      *
      * First these two conditions are checked. If job and event are not
-     * registered they are inserted into configuration and commited.
+     * registered they are inserted into configuration and committed.
      * After what SOffice must be destroyed for proper initialization
      * of <code>JobExecutor</code> after startup. <p>
      *

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_fwl/FilterFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_fwl/FilterFactory.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_fwl/FilterFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_fwl/FilterFactory.java Tue Apr 29 19:13:51 2014
@@ -66,7 +66,7 @@ public class FilterFactory extends TestC
      * <code>com.sun.star.comp.framework.FilterFactory</code>.
      * Prepares relation for
      * <code>XMultiServiceFactory.createInstanceWithArguments</code> method
-     * test. Only filters wich have their service names can be instantiated
+     * test. Only filters which have their service names can be instantiated
      * in some reasons (?). For instantiation used filter type as service
      * name and its name as a parameter. <p>
      */

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_implreg.uno/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_implreg.uno/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_implreg.uno/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_implreg.uno/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'impreg'.</P>
+<P>Contains all test cases for the module 'impreg'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_impreg/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_impreg/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_impreg/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_impreg/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'impreg'.</P>
+<P>Contains all test cases for the module 'impreg'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_insp/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_insp/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_insp/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_insp/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'insp'.</P>
+<P>Contains all test cases for the module 'insp'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_introspection.uno/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_introspection.uno/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_introspection.uno/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_introspection.uno/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'insp'.</P>
+<P>Contains all test cases for the module 'insp'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_inv/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_inv/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_inv/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_inv/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'inv'.</P>
+<P>Contains all test cases for the module 'inv'.</P>
 </BODY>
 </HTML>

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_invadp/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_invadp/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_invadp/package.html (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_invadp/package.html Tue Apr 29 19:13:51 2014
@@ -21,6 +21,6 @@
  ***********************************************************-->
 <HTML>
 <BODY>
-<P>Containes all test cases for the module 'invadp'.</P>
+<P>Contains all test cases for the module 'invadp'.</P>
 </BODY>
 </HTML>
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSpreadsheets.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSpreadsheets.java Tue Apr 29 19:13:51 2014
@@ -116,7 +116,7 @@ public class _XSpreadsheets extends Mult
     * the collection, removes the sheet, tries to insert the sheet with the
     * bad name returned by method <code>badName()</code>. <p>
     * Has <b> OK </b> status if the inserted sheet exists in the collection
     * after first method call and if exception occured during the second call. <p>
     */
     public void _insertNewByName() {
         boolean result = false;
@@ -148,7 +148,7 @@ public class _XSpreadsheets extends Mult
             oObj.removeByName(NewSheet);
         } catch (com.sun.star.uno.RuntimeException e) {
             log.println(
-                    "Expected exception occured during testing 'insertNewByName'");
+                    "Expected exception occurred during testing 'insertNewByName'");
             result &= true;
         } catch (com.sun.star.lang.WrappedTargetException e) {
             log.print("Can't remove sheet '" + NewSheet + "':");
@@ -116,7 +116,7 @@ public class _XSpreadsheets extends Mult
     * bad name returned by method <code>badName()</code>. <p>
     * Has <b> OK </b> status if the inserted sheet exists in the collection
-    * after first method call and if exception occured during the second call. <p>
+    * after first method call and if exception occurred during the second call. <p>
     */
     public void _insertNewByName() {

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_CharacterProperties.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/style/_CharacterProperties.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XRelativeTextContentInsert.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XRelativeTextContentInsert.java Tue Apr 29 19:13:51 2014
@@ -46,7 +46,7 @@ import com.sun.star.uno.XInterface;
  *   the creator which can create instances of
  *   <code>com.sun.star.text.Paragraph</code> service. </li>
  *  <li> <code>'XTEXTINFO'</code> (of type <code>XInstCreator</code>):
- *   the creator which can create instances of soem text content
+ *   the creator which can create instances of some text content
  *   service (objects which implement <code>XTextContent</code>).
  *  </li>
  * <ul> <p>
@@ -67,7 +67,7 @@ public class _XRelativeTextContentInsert
      * using relation and inserted into text. Then an instance
      * of text content is created and inserted after the paragraph. <p>
      *
      * Has <b>OK</b> status if no exceptions occured.
      */
     public void _insertTextContentAfter() {
 
@@ -87,7 +87,7 @@ public class _XRelativeTextContentInsert
             tRes.tested("insertTextContentAfter()",true);
         }
         catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while checking "+
+            log.println("Exception occurred while checking "+
                 "insertTextContentAfter()");
             ex.printStackTrace(log);
             tRes.tested("insertTextContentAfter()",false);
@@ -101,7 +101,7 @@ public class _XRelativeTextContentInsert
      * and inserted before the paragraph which was added into
      * text in <code>insertTextContentAfter</code> method test. <p>
      *
      * Has <b>OK</b> status if no exceptions occured. <p>
      *
      * The following method tests are to be completed successfully before :
      * <ul>
@@ -119,7 +119,7 @@ public class _XRelativeTextContentInsert
             tRes.tested("insertTextContentBefore()",true);
         }
         catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while checking "+
+            log.println("Exception occurred while checking "+
                 "insertTextContentBefore()");
             ex.printStackTrace(log);
             tRes.tested("insertTextContentBefore()",false);
@@ -67,7 +67,7 @@ public class _XRelativeTextContentInsert
      * of text content is created and inserted after the paragraph. <p>
      *
-     * Has <b>OK</b> status if no exceptions occured.
+     * Has <b>OK</b> status if no exceptions occurred.
      */
     public void _insertTextContentAfter() {
@@ -101,7 +101,7 @@ public class _XRelativeTextContentInsert
      * text in <code>insertTextContentAfter</code> method test. <p>
      *
-     * Has <b>OK</b> status if no exceptions occured. <p>
+     * Has <b>OK</b> status if no exceptions occurred. <p>
      *
      * The following method tests are to be completed successfully before :

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XText.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XText.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XText.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XText.java Tue Apr 29 19:13:51 2014
@@ -90,10 +90,10 @@ public class _XText extends MultiMethodT
         // get indexaccess to the tablecollection
         XIndexAccess xIA = info.getCollection();
 
-        // this comparision works just because it has to be at least one
+        // this comparison works just because it has to be at least one
         // table at this point regardless which thread inserted it
         // there is although the possibility that the first threads call
-        // failed, the second not and comparision happens after second threads
+        // failed, the second not and comparison happens after second threads
         // otherwise if something fails it should have thrown an exception
         //tRes.tested("insertTextContent()",    xIA.getCount() > 0 );
 
@@ -110,12 +110,12 @@ public class _XText extends MultiMethodT
         log.println( "test for insertTextContent" );
         try {
             oObj.insertTextContent(oCursor, null, false);
-            log.println("The expected Exception doesn't occured");
+            log.println("The expected Exception doesn't occurred");
             result &= false;
         }
         catch( com.sun.star.lang.IllegalArgumentException iaE ){
             // Some exception.FAILED
-            log.println("Expected Exception occured");
+            log.println("Expected Exception occurred");
             String msg = iaE.getMessage();
             if (msg.equals("")) {
                 log.println("But there is not detailed message");
@@ -157,7 +157,7 @@ public class _XText extends MultiMethodT
             return;
         }
 
         // no exception occured so it works
         tRes.tested( "removeTextContent()", true );
 
     }
@@ -157,7 +157,7 @@ public class _XText extends MultiMethodT
         }
 
-        // no exception occured so it works
+        // no exception occurred so it works
         tRes.tested( "removeTextContent()", true );
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java Tue Apr 29 19:13:51 2014
@@ -119,19 +119,19 @@ public class _XTextFieldsSupplier extend
                     the_Cursor, oContent, true);
 
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while creating test Object.");
+                log.println("Exception occurred while creating test Object.");
                 e.printStackTrace(log);
                 throw new StatusException("Couldn't insert textField.URL", e);
             } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-                log.println("Exception occured while creating test Object.");
+                log.println("Exception occurred while creating test Object.");
                 e.printStackTrace(log);
                 throw new StatusException("Couldn't insert textField.URL", e);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while creating test Object.");
+                log.println("Exception occurred while creating test Object.");
                 e.printStackTrace(log);
                 throw new StatusException("Couldn't insert textField.URL", e);
             } catch (com.sun.star.uno.Exception e) {
-                log.println("Exception occured while creating test Object.");
+                log.println("Exception occurred while creating test Object.");
                 e.printStackTrace(log);
                 throw new StatusException("Couldn't insert textField.URL", e);
             }
@@ -171,7 +171,7 @@ public class _XTextFieldsSupplier extend
     /**
      * Just for convenience: log the exception and set the method false.
      * @param method The name of the method to set to false.
      * @param e The Exception that occured.
      */
     private void setMethodFalse(String method, Exception e) {
         log.println("Exception while executing '" + method + "'");
@@ -171,7 +171,7 @@ public class _XTextFieldsSupplier extend
      * Just for convenience: log the exception and set the method false.
      * @param method The name of the method to set to false.
-     * @param e The Exception that occured.
+     * @param e The Exception that occurred.
      */
     private void setMethodFalse(String method, Exception e) {

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java Tue Apr 29 19:13:51 2014
@@ -170,7 +170,7 @@ public class _XDocumentHandler extends M
       * Sets document locator to dummy locator implementation and
          * calls the <code>startDocument</code> method. <p>
          *
      * Has <b> OK </b> status if no runtime exceptions occured.
      */
     public void _startDocument() {
         if (ToBeSkipped) {
@@ -199,11 +199,11 @@ public class _XDocumentHandler extends M
 
         /**
          * This test is finally executed. It finishes XML data
-         * transfering with <code>endDocument</code> method call. <p>
+         * transferring with <code>endDocument</code> method call. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during
          * the whole transfering and if the appropriate changes
          * occured in the document where XML data was trnsfered to.
          * This check is performed by checker relation.
          */
     public void _endDocument() {
@@ -236,8 +236,8 @@ public class _XDocumentHandler extends M
          * Transfers XML data obtained from relation
          * <code>'XDocumentHandler.XMLData'</code>. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests. <p>
          *
          * Exact checking of XML transfer is made in <code>endDocument</code>
@@ -301,8 +301,8 @@ public class _XDocumentHandler extends M
         /**
          * Does nothing. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
     public void _endElement() {
@@ -320,8 +320,8 @@ public class _XDocumentHandler extends M
         /**
          * Does nothing. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
     public void _characters() {
@@ -339,8 +339,8 @@ public class _XDocumentHandler extends M
         /**
          * Does nothing. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
     public void _ignorableWhitespace() {
@@ -358,8 +358,8 @@ public class _XDocumentHandler extends M
         /**
          * Does nothing. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
     public void _processingInstruction() {
@@ -377,8 +377,8 @@ public class _XDocumentHandler extends M
         /**
          * Does nothing. <p>
          *
          * Has <b>OK</b> status if no exceptions occured during XML data
          * transfering in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
     public void _setDocumentLocator() {
@@ -390,7 +390,7 @@ public class _XDocumentHandler extends M
 
         boolean result = locatorResult ;
         if (locatorException != null) {
-            log.println("Exception occured during setDocumentLocator() call:") ;
+            log.println("Exception occurred during setDocumentLocator() call:") ;
             locatorException.printStackTrace(log) ;
             log.println("Wrapped exception :"
                 + locatorException.WrappedException) ;
@@ -170,7 +170,7 @@ public class _XDocumentHandler extends M
          * calls the <code>startDocument</code> method. <p>
          *
-     * Has <b> OK </b> status if no runtime exceptions occured.
+     * Has <b> OK </b> status if no runtime exceptions occurred.
      */
     public void _startDocument() {
@@ -199,11 +199,11 @@ public class _XDocumentHandler extends M
          *
-         * Has <b>OK</b> status if no exceptions occured during
-         * the whole transfering and if the appropriate changes
-         * occured in the document where XML data was trnsfered to.
+         * Has <b>OK</b> status if no exceptions occurred during
+         * the whole transferring and if the appropriate changes
+         * occurred in the document where XML data was trnsfered to.
          * This check is performed by checker relation.
          */
@@ -236,8 +236,8 @@ public class _XDocumentHandler extends M
          * <code>'XDocumentHandler.XMLData'</code>. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests. <p>
          *
@@ -301,8 +301,8 @@ public class _XDocumentHandler extends M
          * Does nothing. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
@@ -320,8 +320,8 @@ public class _XDocumentHandler extends M
          * Does nothing. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
@@ -339,8 +339,8 @@ public class _XDocumentHandler extends M
          * Does nothing. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
@@ -358,8 +358,8 @@ public class _XDocumentHandler extends M
          * Does nothing. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */
@@ -377,8 +377,8 @@ public class _XDocumentHandler extends M
          * Does nothing. <p>
          *
-         * Has <b>OK</b> status if no exceptions occured during XML data
-         * transfering in <code>startDocument</code> and
+         * Has <b>OK</b> status if no exceptions occurred during XML data
+         * transferring in <code>startDocument</code> and
          * <code>startElement</code> method tests.
          */

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_acceptor/package.html
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_acceptor/package.html?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================